@@ -1,14 +1,23 @@
-package Metabase::Fact;
+# 
+# This file is part of Metabase-Fact
+# 
+# This software is Copyright (c) 2010 by David Golden.
+# 
+# This is free software, licensed under:
+# 
+#   The Apache License, Version 2.0, January 2004
+# 
 use 5.006;
 use strict;
 use warnings;
-use Metabase::Resource;
+package Metabase::Fact;
+our $VERSION = '0.008';
+# ABSTRACT: base class for Metabase Facts
+
+use Carp ();
 use Data::GUID guid_string => { -as => '_guid' };
 use JSON ();
-use Carp ();
-
-our $VERSION = '0.007';
-$VERSION = eval $VERSION;
+use Metabase::Resource;
 
 #--------------------------------------------------------------------------#
 # main API methods -- shouldn't be overridden
@@ -369,12 +378,18 @@ sub validate_content {
 
 1;
 
-__END__
+
+
+=pod
 
 =head1 NAME
 
 Metabase::Fact - base class for Metabase Facts
 
+=head1 VERSION
+
+version 0.008
+
 =head1 SYNOPSIS
 
   # defining the fact class
@@ -574,7 +589,7 @@ object.
 =head2 upgrade_fact
 
   MyFact->upgrade_fact( $struct );
-  
+
 This method will be called when initializing a fact from a data structure that
 claims to be of a schema version other than the schema version reported by the
 loaded class's C<default_schema_version> method.  It will be passed the hashref
@@ -783,26 +798,23 @@ L<http://rt.cpan.org/Dist/Display.html?Queue=Metabase-Fact>
 When submitting a bug or request, please include a test-file or a patch to an
 existing test-file that illustrates the bug or desired feature.
 
-=head1 AUTHOR
+=head1 AUTHORS
 
- David A. Golden (DAGOLDEN)
- Ricardo J. B. Signes (RJBS)
+  David Golden <dagolden@cpan.org>
+  Ricardo Signes <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-  Portions copyright (c) 2008-2009 by David A. Golden
-  Portions copyright (c) 2008-2009 by Ricardo J. B. Signes
+This software is Copyright (c) 2010 by David Golden.
 
-Licensed under the same terms as Perl itself (the "License").
-You may not use this file except in compliance with the License.
-A copy of the License was distributed with this file or you may obtain a
-copy of the License from http://dev.perl.org/licenses/
+This is free software, licensed under:
 
-Unless required by applicable law or agreed to in writing, software
-distributed under the License is distributed on an "AS IS" BASIS,
-WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-See the License for the specific language governing permissions and
-limitations under the License.
+  The Apache License, Version 2.0, January 2004
 
 =cut
 
+
+__END__
+
+
+
