@@ -1,11 +1,20 @@
-package Metabase::Resource;
+# 
+# This file is part of Metabase-Fact
+# 
+# This software is Copyright (c) 2010 by David Golden.
+# 
+# This is free software, licensed under:
+# 
+#   The Apache License, Version 2.0, January 2004
+# 
 use 5.006;
 use strict;
 use warnings;
-use Carp ();
+package Metabase::Resource;
+our $VERSION = '0.008';
+# ABSTRACT: factory class for Metabase resource descriptors
 
-our $VERSION = '0.007';
-$VERSION = eval $VERSION;
+use Carp ();
 
 #--------------------------------------------------------------------------#
 # main API methods -- shouldn't be overridden
@@ -84,7 +93,12 @@ sub _cache  { return $_[0]->{_cache} }
 
 sub _types  { return $_[0]->{_types} }
 
-sub resource { return $_[0]->{resource} }
+# Don't cause segfault with perl-5.6.1 by
+# overloading undef stuff...
+sub resource {
+  return '' unless defined $_[0]->{resource};
+  return "$_[0]->{resource}";
+}
 
 sub metadata {
   my ($self) = @_;
@@ -107,12 +121,18 @@ sub validate {
 
 1;
 
-__END__
+
+
+=pod
 
 =head1 NAME
 
 Metabase::Resource - factory class for Metabase resource descriptors
 
+=head1 VERSION
+
+version 0.008
+
 =head1 SYNOPSIS
 
   my $resource = Metabase::Resource->new(
@@ -275,27 +295,22 @@ L<http://rt.cpan.org/Dist/Display.html?Queue=Metabase-Fact>
 When submitting a bug or request, please include a test-file or a patch to an
 existing test-file that illustrates the bug or desired feature.
 
-=head1 AUTHOR
+=head1 AUTHORS
 
-Primary Authors and other Contributors are listed below:
-
-  * David A. Golden (DAGOLDEN)
-  * Ricardo Signes  (RJBS)
+  David Golden <dagolden@cpan.org>
+  Ricardo Signes <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-  Copyright (c) 2010 by David A. Golden, Ricardo Signes and Contributors
+This software is Copyright (c) 2010 by David Golden.
 
-Licensed under the same terms as Perl itself (the "License").
-You may not use this file except in compliance with the License.
-A copy of the License was distributed with this file or you may obtain a
-copy of the License from http://dev.perl.org/licenses/
+This is free software, licensed under:
 
-Unless required by applicable law or agreed to in writing, software
-distributed under the License is distributed on an "AS IS" BASIS,
-WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-See the License for the specific language governing permissions and
-limitations under the License.
+  The Apache License, Version 2.0, January 2004
 
 =cut
 
+
+__END__
+
+
