@@ -1,14 +1,22 @@
-package Metabase::Resource::metabase::fact;
+# 
+# This file is part of Metabase-Fact
+# 
+# This software is Copyright (c) 2010 by David Golden.
+# 
+# This is free software, licensed under:
+# 
+#   The Apache License, Version 2.0, January 2004
+# 
 use 5.006;
 use strict;
 use warnings;
+package Metabase::Resource::metabase::fact;
+our $VERSION = '0.008';
+# ABSTRACT: class for Metabase facts
+
 use Carp ();
 
-our $VERSION = '0.007';
-$VERSION = eval $VERSION;
-
-use Metabase::Resource::metabase;
-our @ISA = qw(Metabase::Resource::metabase);
+use base 'Metabase::Resource::metabase';
 
 sub _init {
   my ($self) = @_;
@@ -28,12 +36,18 @@ sub validate {
 
 1;
 
-__END__
+
+
+=pod
 
 =head1 NAME
 
 Metabase::Resource::metabase::fact - class for Metabase facts
 
+=head1 VERSION
+
+version 0.008
+
 =head1 SYNOPSIS
 
   my $resource = Metabase::Resource->new(
@@ -64,27 +78,22 @@ L<http://rt.cpan.org/Dist/Display.html?Queue=Metabase-Fact>
 When submitting a bug or request, please include a test-file or a patch to an
 existing test-file that illustrates the bug or desired feature.
 
-=head1 AUTHOR
+=head1 AUTHORS
 
-Primary Authors and other Contributors are listed below:
-
-  * David A. Golden (DAGOLDEN)
-  * Ricardo Signes  (RJBS)
+  David Golden <dagolden@cpan.org>
+  Ricardo Signes <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-  Copyright (c) 2010 by David A. Golden, Ricardo Signes and Contributors
+This software is Copyright (c) 2010 by David Golden.
 
-Licensed under the same terms as Perl itself (the "License").
-You may not use this file except in compliance with the License.
-A copy of the License was distributed with this file or you may obtain a
-copy of the License from http://dev.perl.org/licenses/
+This is free software, licensed under:
 
-Unless required by applicable law or agreed to in writing, software
-distributed under the License is distributed on an "AS IS" BASIS,
-WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-See the License for the specific language governing permissions and
-limitations under the License.
+  The Apache License, Version 2.0, January 2004
 
 =cut
 
+
+__END__
+
+
