@@ -1,11 +1,20 @@
-package Metabase::User::Profile;
+# 
+# This file is part of Metabase-Fact
+# 
+# This software is Copyright (c) 2010 by David Golden.
+# 
+# This is free software, licensed under:
+# 
+#   The Apache License, Version 2.0, January 2004
+# 
 use 5.006;
 use strict;
 use warnings;
-our $VERSION = '0.007';
-$VERSION = eval $VERSION; ## no critic
+package Metabase::User::Profile;
+our $VERSION = '0.008';
+# ABSTRACT: Metabase report class for user-related facts
 
-use Carp;
+use Carp ();
 use Data::GUID guid_string => { -as => '_guid' };
 
 use base 'Metabase::Report';
@@ -63,12 +72,18 @@ sub report_spec {
   
 1;
 
-__END__
+
+
+=pod
 
 =head1 NAME
 
 Metabase::User::Profile - Metabase report class for user-related facts
 
+=head1 VERSION
+
+version 0.008
+
 =head1 SYNOPSIS
 
   use Metabase::User::Profile;
@@ -138,28 +153,22 @@ L<http://rt.cpan.org/Dist/Display.html?Queue=Metabase-Fact>
 When submitting a bug or request, please include a test-file or a patch to an
 existing test-file that illustrates the bug or desired feature.
 
-=head1 AUTHOR
+=head1 AUTHORS
 
-=over 
-
-=item * David A. Golden (DAGOLDEN)
-
-=back
+  David Golden <dagolden@cpan.org>
+  Ricardo Signes <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2009-2010 by David A. Golden
+This software is Copyright (c) 2010 by David Golden.
 
-Licensed under the same terms as Perl itself (the "License").
-You may not use this file except in compliance with the License.
-A copy of the License was distributed with this file or you may obtain a 
-copy of the License from http://dev.perl.org/licenses/
+This is free software, licensed under:
 
-Unless required by applicable law or agreed to in writing, software
-distributed under the License is distributed on an "AS IS" BASIS,
-WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-See the License for the specific language governing permissions and
-limitations under the License.
+  The Apache License, Version 2.0, January 2004
 
 =cut
 
+
+__END__
+
+
